@@ -34,7 +34,7 @@ class SecsS05F05(SecsStreamFunction):
     _stream = 5
     _function = 5
 
-    _data_format = [ALID]
+    _data_format = ALID
 
     _to_host = False
     _to_equipment = True
